@@ -28,4 +28,11 @@ class CRUDOAuthUser(CRUDTree):
             if hasattr(item, "password"):
                 delattr(item, "password")
 
-        return super(CRUDOAuthUser, cls).update(db=db, pk=pk, item=item, **kwargs)
\ No newline at end of file
+        return super(CRUDOAuthUser, cls).update(db=db, pk=pk, item=item, **kwargs)
+
+    @classmethod
+    def all(cls, **kwargs):
+        kwargs.update({
+            "order": [("sort", "asc")]
+        })
+        return super().all(**kwargs)
